import { 
  select, 
  csv, 
  scaleLinear,  
  max, 
  scalePoint, 
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');
const height = +svg.attr('height');
const width = parseFloat(svg.attr('width')); 

const render = (data) => {
  
  const xValue = (d) => { 
      return d.population 
    };
  const yValue = (d) =>{
  	return d.country;
  };
  
  const margin = { top: 50, right: 40, bottom: 80, left: 200 };
	const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth])
  	.nice(); //.nice makes grid lines end on a tick. 
  
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.7);
  
  //set svg margins 
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${50})`);
  
  const xAxisTickFormat = number => 
  	format('.3s')(number)
  		.replace('G', 'B');

  const xAxis = axisBottom(xScale)
  								.tickFormat(xAxisTickFormat)
  								.tickSize(-innerHeight);
  
  const yAxis = axisLeft(yScale)
  								.tickSize(-innerWidth);  
    
	
  const yAxisG = g.append('g')
  	.call(yAxis)
  //remove tick
  	.selectAll('.domain')
  	.remove();
  
          
          
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
    
  xAxisG.select('.domain',)
  	.remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 60)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text('Population');
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue( d)))
  		.attr('r', 15);
  
  g.append('text')
  	.attr('class', 'title')
  	.text("Top 10 Most Populous Countries")
  	.attr('y', -10);
  
}
 
csv('https://vizhub.com/mellerjakub88/datasets/auto-mpg.csv')
  .then(data =>{
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    })
  render(data);
});